@@ -19,32 +19,38 @@ import os
 import os.path
 import logging
 import mimetypes
-from flask import (
-    abort,
-    jsonify,
-    request,
-    send_file
-)
-from airflow_code_editor.commons import (
-    HTTP_404_NOT_FOUND
-)
+from flask import abort, request, send_file
+from airflow.version import version
+from airflow_code_editor.commons import HTTP_404_NOT_FOUND
 from airflow_code_editor.utils import (
+    get_plugin_boolean_config,
+    get_plugin_int_config,
     git_absolute_path,
     execute_git_command,
-    normalize_path
+    error_message,
+    normalize_path,
+    prepare_api_response,
 )
 
-__all__ = [
-    'AbstractCodeEditorView'
-]
+# Optional Code Formatter
+try:
+    import black
+except ImportError:
+    black = None
+
+
+__all__ = ['AbstractCodeEditorView']
+
+AIRFLOW_MAJOR_VERSION = int(version.split('.')[0])
 
 
 class AbstractCodeEditorView(object):
+    airflow_major_version = AIRFLOW_MAJOR_VERSION
 
-    def _index(self, session=None):
+    def _index(self):
         return self._render('index')
 
-    def _save(self, session=None, path=None):
+    def _save(self, path=None):
         try:
             data = request.form['data']
             # Newline fix (remove cr)
@@ -54,40 +60,32 @@ class AbstractCodeEditorView(object):
             with open(fullpath, 'w') as f:
                 f.write(data)
                 f.write('\n')
-            return jsonify({
-                'path': normalize_path(path)
-            })
+            return prepare_api_response(path=normalize_path(path))
         except Exception as ex:
             logging.error(ex)
-            if hasattr(ex, 'strerror'):
-                message = ex.strerror
-            elif hasattr(ex, 'message'):
-                message = ex.message
-            else:
-                message = str(ex)
-            return jsonify({
-                'path': normalize_path(path),
-                'error': {
-                    'message': 'Error saving {path}: {message}'.format(path=path, message=message)
-                }
-            })
+            return prepare_api_response(
+                path=normalize_path(path),
+                error_message='Error saving {path}: {message}'.format(
+                    path=path, message=error_message(ex)
+                ),
+            )
 
-    def _git_repo(self, session, path):
+    def _git_repo(self, path):
         if request.method == 'POST':
-            return self._git_repo_post(session, path)
+            return self._git_repo_post(path)
         else:
-            return self._git_repo_get(session, path)
+            return self._git_repo_get(path)
 
-    def _git_repo_get(self, session, path):
+    def _git_repo_get(self, path):
         " Get a file from GIT (invoked by the HTTP GET method) "
         return execute_git_command(["cat-file", "-p", path])
 
-    def _git_repo_post(self, session, path):
+    def _git_repo_post(self, path):
         " Execute a GIT command (invoked by the HTTP POST method) "
         git_args = request.form.getlist('args[]')
         return execute_git_command(git_args)
 
-    def _load(self, session, path):
+    def _load(self, path):
         " Send the contents of a file to the client "
         try:
             path = normalize_path(path)
@@ -95,7 +93,9 @@ class AbstractCodeEditorView(object):
                 # Download git blob - path = '~git/<hash>/<name>'
                 _, path, filename = path.split('/', 3)
                 response = execute_git_command(["cat-file", "-p", path])
-                response.headers['Content-Disposition'] = 'attachment; filename="%s"' % filename
+                response.headers['Content-Disposition'] = (
+                    'attachment; filename="%s"' % filename
+                )
                 try:
                     content_type = mimetypes.guess_type(filename)[0]
                     if content_type:
@@ -110,3 +110,27 @@ class AbstractCodeEditorView(object):
         except Exception as ex:
             logging.error(ex)
             abort(HTTP_404_NOT_FOUND)
+
+    def _format(self):
+        " Format code "
+        if black is None:
+            return prepare_api_response(
+                error_message='black dependency is not installed: to install black `pip install black`'
+            )
+        try:
+            data = request.form['data']
+            # Newline fix (remove cr)
+            data = data.replace('\r', '').rstrip()
+            mode = black.Mode(
+                string_normalization=get_plugin_boolean_config('string_normalization'),
+                line_length=get_plugin_int_config('line_length'),
+            )
+            data = black.format_str(src_contents=data, mode=mode)
+            return prepare_api_response(data=data)
+        except Exception as ex:
+            logging.error(ex)
+            return prepare_api_response(
+                error_message='Error formatting: {message}'.format(
+                    message=error_message(ex)
+                )
+            )
